Vertical modes
==============

Standard vertical modes, , :math:`{\mathsf{p}}_n (z)`, are the
eigenvectors of the “stretching matrix”

.. math:: {\mathsf{S}}\,{\mathsf{p}}_n = -R_n^{-2}\, {\mathsf{p}}_n\,,

where the :math:`R_n` is by definition the n’th deformation radius
(e.g., `Flierl
1978 <http://www.sciencedirect.com/science/article/pii/0377026578900027>`__).
These orthogonal modes :math:`{\mathsf{p}}_n` are normalized to have
unitary :math:`L2`-norm

.. math:: \frac{1}{H}\int_{-H}^{0} {\mathsf{p}}_n {\mathsf{p}}_m {{\rm d}}z = \delta_{nm}{\, ,}

where :math:`\delta_{mn}`.
